/*
 * Copyright (c) 1998-2010 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.server.repository;

import java.io.InputStream;

import com.caucho.repository.DataSource;
import com.caucho.server.cache.TempFileInode;

/**
 * The module repository holds the module jars for osgi and ivy.
 */
public class InodeDataSource implements DataSource
{
  private String _name;
  private TempFileInode _inode;

  InodeDataSource(String name, TempFileInode inode)
  {
    _name = name;
    _inode = inode;
  }

  public String getName()
  {
    return _name;
  }

  public InputStream openInputStream()
  {
    return _inode.openInputStream();
  }

  public void close()
  {
    TempFileInode inode = _inode;
    _inode = null;

    if (inode != null)
      inode.free();
  }

  protected void finalize()
  {
    close();
  }
}
